//
//  ViewController.m
//  ANTDemo
//
//  Created by Umeno Katsuhiko on 13/06/10.
//  Copyright (c) 2013年 Umeno Katsuhiko. All rights reserved.
//

#import "ViewController.h"
#import "BCANTAccessory.h"
#import "BCANT.h"
#import "BCTemperatureSensor.h"
#import "BCHumiditySensor.h"
#import "BCPressureSensor.h"

#define PUBLIC_CHANNEL  0
#define TEMP_SENSOR_DEVICE_NUM  33
#define HUMID_SENSOR_DEVICE_NUM 35
#define PRESS_SENSOR_DEVICE_NUM 34

enum {
    TYPE_TEMP_SENSOR    = 1,
    TYPE_HUMID_SENSOER,
    TYPE_PRESS_SENSOR,
};


@interface ViewController ()
{
    BCTemperatureSensor* _tempSensor;
    BCHumiditySensor*    _humidSensor;
    BCPressureSensor*    _pressSensor;
}
@end

@implementation ViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    // ANT Adapter notification Setting
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(accessoryDidConnected:) name:BCANTAccessoryDidConnected object:nil];
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(accessoryDidDisconnected:) name:BCANTAccessoryDidDisconnected object:nil];
    
    // TemperatureSensor notification
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(temperatureSensorUpdate:) name:BCTemperatureSensorUpdate object:nil];
    // Humidity Sensor notification
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(humiditySensorUpdate:) name:BCHumiditySensorUpdate object:nil];
    // PressureSensor notification
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(pressureSensorUpdate:) name:BCPressureSensorUpdate object:nil];
    
    // 1st make BCANTAccessory instance
    BCANTAccessory* acc = [BCANTAccessory sharedANTAccessory];
    NSLog(@"AdapterConnected:%@", [acc isAccessoryReady] ? @"YES" : @"NO");
    
    
    // Setup Sensors
    //[self sensorSetup];

}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)toInterfaceOrientation
{
    if ([UIDevice currentDevice].userInterfaceIdiom == UIUserInterfaceIdiomPad) {
        if (toInterfaceOrientation == UIInterfaceOrientationLandscapeLeft ||
            toInterfaceOrientation == UIInterfaceOrientationLandscapeRight) {
            return YES;
        }
    } else {
        if (toInterfaceOrientation == UIInterfaceOrientationPortrait ||
            toInterfaceOrientation == UIInterfaceOrientationPortraitUpsideDown) {
            return YES;
        }
    }
    
    return NO;
}

// for iOS 6.0 or later
- (BOOL)shouldAutorotate
{
    return YES;
}

- (NSUInteger)supportedInterfaceOrientations
{
    if ([UIDevice currentDevice].userInterfaceIdiom == UIUserInterfaceIdiomPad) {
        return UIInterfaceOrientationMaskLandscape;
    }
    
    return (UIInterfaceOrientationMaskPortrait | UIInterfaceOrientationMaskPortraitUpsideDown);
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (void) sensorSetup
{
    BCANT* ant = [BCANT shardANT];
    
    UInt8 channel;
    
    if ([ant getFreeChannel:&channel]) {
        _tempSensor = [[BCTemperatureSensor alloc] initWithChannelNumber:channel];
        _tempSensor.type = TYPE_TEMP_SENSOR;
        _tempSensor.delegate = self;
    }

    if ([ant getFreeChannel:&channel]) {
        _humidSensor = [[BCHumiditySensor alloc] initWithChannelNumber:channel];
        _humidSensor.type = TYPE_HUMID_SENSOER;
        _humidSensor.delegate = self;
    }
    
    if ([ant getFreeChannel:&channel]) {
        _pressSensor = [[BCPressureSensor alloc] initWithChannelNumber:channel];
        _pressSensor.type = TYPE_PRESS_SENSOR;
        _pressSensor.delegate = self;
    }

}

- (void) releaseSensor
{
    _tempSensor.delegate = nil;
    _tempSensor = nil;
    
    _humidSensor.delegate = nil;
    _humidSensor = nil;
    
    _pressSensor.delegate = nil;
    _pressSensor = nil;
}

- (void) didSensorStateChanged:(NSInteger)type state:(ANTSensorState)state sensor:(SensorCommon*)sensor
{
    if (state == BC_SENSOR_STATE_CHANNEL_CLOSED) {
        switch (type) {
            case TYPE_TEMP_SENSOR:
                self.tempLabel.text = @"--";
                [_tempSensor start:TEMP_SENSOR_DEVICE_NUM];
                break;
            case TYPE_HUMID_SENSOER:
                self.humidLabel.text = @"--";
                [_humidSensor start:HUMID_SENSOR_DEVICE_NUM];
                break;
            case TYPE_PRESS_SENSOR:
                self.pressLabel.text = @"--";
                [_pressSensor start:PRESS_SENSOR_DEVICE_NUM];
                break;
        }
    }
}

- (void) temperatureSensorUpdate:(NSNotification*) notification
{
    BCTemperatureSensor* tempSensor = [notification object];
    
    self.tempLabel.text = [NSString stringWithFormat:@"%d", tempSensor.temperature];
}

- (void) humiditySensorUpdate:(NSNotification*) notification
{
    BCHumiditySensor* humidSensor = [notification object];

    self.humidLabel.text = [NSString stringWithFormat:@"%d", humidSensor.humidity];
}

- (void) pressureSensorUpdate:(NSNotification*) notification
{
    BCPressureSensor* pressSensor = [notification object];
    
    self.pressLabel.text = [NSString stringWithFormat:@"%.1f", pressSensor.pressure + 0.05];
}

- (void) accessoryDidConnected:(NSNotification*) notification
{
    NSLog(@"** accessoryDidConnected");
    self.adapterConnectedLabel.text = @"YES";
    
    BCANTAccessory* acc = [BCANTAccessory sharedANTAccessory];
    // LED
    [acc LEDBrink:0 cycle:300];//[NSThread sleepForTimeInterval:0.5];
    [acc LEDBrink:1 cycle:350];//[NSThread sleepForTimeInterval:0.5];
    
    // Setup Sensors
    [self sensorSetup];
    
    [_tempSensor start:TEMP_SENSOR_DEVICE_NUM];
    [NSThread sleepForTimeInterval:1.0];
    
    [_humidSensor start:HUMID_SENSOR_DEVICE_NUM];
    [NSThread sleepForTimeInterval:1.0];
    
    [_pressSensor start:PRESS_SENSOR_DEVICE_NUM];
     [NSThread sleepForTimeInterval:1.0];
    
    
    
}

- (void) accessoryDidDisconnected:(NSNotification*) notification
{
    NSLog(@"** accessoryDidDisconnected");
    self.adapterConnectedLabel.text = @"NO";
    
    self.tempLabel.text = @"--";
    self.humidLabel.text = @"--";
    self.pressLabel.text = @"--";
    
    [self releaseSensor];
}

@end
